/// <reference types="node" />
import type { Either } from '@lokalise/node-core';
import type { BarrierResult, MessageInvalidFormatError, MessageValidationError, QueuePublisherOptions, SyncPublisher } from '@message-queue-toolkit/core';
import type { ZodSchema } from 'zod';
import type { AMQPLocator, AMQPCreationConfig, AMQPDependencies } from './AbstractAmqpService';
import { AbstractAmqpService } from './AbstractAmqpService';
export type AMQPPublisherOptions<MessagePayloadType extends object> = QueuePublisherOptions<AMQPCreationConfig, AMQPLocator, MessagePayloadType> & {
    exchange?: string;
};
export declare abstract class AbstractAmqpPublisher<MessagePayloadType extends object, MessageOptionsType> extends AbstractAmqpService<MessagePayloadType> implements SyncPublisher<MessagePayloadType, MessageOptionsType> {
    private readonly messageSchemaContainer;
    protected readonly exchange?: string;
    private initPromise?;
    constructor(dependencies: AMQPDependencies, options: AMQPPublisherOptions<MessagePayloadType>);
    publish(message: MessagePayloadType, options: MessageOptionsType): void;
    protected abstract publishInternal(message: Buffer, options: MessageOptionsType): void;
    protected resolveSchema(message: MessagePayloadType): Either<Error, ZodSchema<MessagePayloadType>>;
    protected resolveMessage(): Either<MessageInvalidFormatError | MessageValidationError, unknown>;
    protected processPrehandlers(): Promise<unknown>;
    protected preHandlerBarrier<BarrierOutput>(): Promise<BarrierResult<BarrierOutput>>;
    protected resolveNextFunction(): () => void;
    close(): Promise<void>;
    processMessage(): Promise<Either<'retryLater', 'success'>>;
}
